JWK

Struct JWK 

pub struct JWK(pub Jwk);
Encapsulation of JSON Web Keys, provided by the josekit crate underneath. Serialization omits the private key fields deliberately according to DID spec, as it is assumed for these purposes it will be used in a decentralized identity document.

See https://www.w3.org/TR/did-core/#verification-material for more information.

Tuple Fields

0: Jwk

Implementations

Source

impl JWK

pub fn new() -> Result<Self, Error>

Creates a new JWK and generates a key for it. The underlying key will have private key material.

pub fn new_from_bytes(bytes: &[u8]) -> Result<Self, Error>

Creates a new JWK struct from an existing series of bytes

pub fn to_public_only(&self) -> Result<Self, Error>

Erases the private key material and creates a new struct from the result.